OC.L10N.register(
    "photos",
    {
    "Photos" : "Fotos",
    "Your memories under your control" : "O seus recordos baixo o seu control",
    "Videos" : "Vídeos",
    "People" : "Xente",
    "Folders" : "Cartafoles",
    "Favorites" : "Favoritos",
    "Shared with you" : "Compartido con vostede",
    "Tags" : "Etiquetas",
    "Locations" : "Localizacións",
    "Back" : "Atrás",
    "Save" : "Gardar",
    "Open the full size \"{name}\" image" : "Abrir a imaxe «{name}» a tamaño completo",
    "Open the \"{name}\" sub-directory" : "Abrir o subdirectorio «{name}»",
    "Back to {folder}" : "Volver a {folder}",
    "Share this folder" : "Compartir este cartafol",
    "Enable squared photos view" : "Activar a vista de fotos cadradas",
    "View" : "Ver",
    "An error occurred" : "Produciuse un erro",
    "Favorite" : "Favorito",
    "Remove from favorites" : "Retirar de favoritos",
    "No photos in here" : "Aquí non hai fotos",
    "No tags yet" : "Non hai nada etiquetado",
    "Photos with tags will show up here" : "As fotos etiquetadas aparecerán aquí",
    "Add" : "Engadir",
    "Download" : "Descargar",
    "Delete selection" : "Eliminar a selección",
    "Delete" : "Eliminar",
    "Tagged photos" : "Fotos etiquetadas",
    "Your photos" : "As súas fotos",
    "Your videos" : "Os seus vídeos",
    "Your folders" : "Os seus cartafoles",
    "Settings" : "Axustes"
},
"nplurals=2; plural=(n != 1);");
